@@ -1,4 +1,4 @@
-from .config import HOST, PORT, USE_SSL, PROTOCOL
+from .config import HOST, PORT, USE_SSL, PROTOCOL, USER, SECRET
 from elasticsearch import Elasticsearch
 
 
@@ -17,7 +17,8 @@ class ElasticSearchClient:
             ElasticSearchClient.client = Elasticsearch(
                 hosts=hosts,
                 use_ssl=USE_SSL,
-                scheme=PROTOCOL
+                scheme=PROTOCOL,
+                http_auth=(USER, SECRET)
             )
         return ElasticSearchClient.client
 
