@@ -3,4 +3,5 @@ from .is_authenticated import IsAuthenticated
 from .is_staff import IsStaff
 from .has_permission import HasPermission
 from .is_member import IsMember
-from .token import TamarinTokenSerializer
+from .token import HolgerTokenSerializer, HolgerTokenObtainPairView, HolgerRefreshView
+from rest_framework_simplejwt.tokens import AccessToken
